package
Version:
v0.0.0-...-a0ebf9c
Opens a new window with list of versions in this module.
Published: Jan 13, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Group[T any] struct {
}
Do 执行并返回给定函数的结果,确保一次只有一个给定键的执行正在进行中。
如果出现重复项,重复调用者将等待原始调用者完成并收到相同的结果。
返回值 shared 用于指示值 v 是否被提供给了多个调用方。
DoChan 类似于Do,但返回一个通道,当结果准备就绪时,该通道将接收结果。
返回的通道不会关闭。
删除传入的key,这样后续调用此key时,请求不会阻塞。
Source Files
¶
Click to show internal directories.
Click to hide internal directories.